@@ -1,3 +1,12 @@
+"""
+Requires the iso3166_ package which can be installed with:
+
+.. _iso3166: https://pypi.org/project/iso3166/
+
+.. code-block:: bash
+
+    $ python3 -m pip install phantom-types[iso3166]
+"""
 from __future__ import annotations
 
 from typing import Final
@@ -28,6 +37,11 @@ class InvalidCountryCode(TypeError):
 
 
 def normalize_alpha2_country_code(country_code: str) -> Alpha2:
+    """
+    Normalize mixed case country code.
+
+    :raises InvalidCountryCode:
+    """
     normalized = country_code.upper()
     if not is_alpha2_country_code(normalized):
         raise InvalidCountryCode
@@ -37,6 +51,11 @@ def normalize_alpha2_country_code(country_code: str) -> Alpha2:
 class Alpha2(str, Phantom, predicate=is_alpha2_country_code):
     @classmethod
     def parse(cls, instance: object) -> Alpha2:
+        """
+        Normalize mixed case country code.
+
+        :raises InvalidCountryCode:
+        """
         return normalize_alpha2_country_code(parse_str(instance))
 
 
