@@ -1,3 +1,18 @@
+"""
+Types describing collections with size boundaries. These types should only be used with
+immutable collections. There is a naive check that eliminates some of the most common
+mutable collections in the instance check. However, a guaranteed check is probably
+impossible to implement, so some amount of developer discipline is required.
+
+Sized types are created by subclassing ``PhantomSized`` and providing a predicate that
+will be called with the size of the tested collection. For instance, ``NonEmpty`` is
+implemented using ``len=numeric.greater(0)``.
+
+This made-up type would describe sized collections with between 5 and 10 ints::
+
+    class SpecificSize(PhantomSized[int], len=numeric.greater(0)):
+        ...
+"""
 from typing import Any
 from typing import Final
 from typing import Generic
@@ -20,6 +35,7 @@ from .predicates import generic
 from .predicates import numeric
 
 __all__ = (
+    "SizedIterable",
     "PhantomSized",
     "NonEmpty",
     "Empty",
@@ -32,7 +48,7 @@ T = TypeVar("T", bound=object, covariant=True)
 
 @runtime_checkable
 class SizedIterable(Sized, Iterable[T], Protocol[T]):
-    ...
+    """Intersection of :py:class:`typing.Sized` and :py:class:`typing.Iterable`."""
 
 
 # This raises a mypy error because disallow_subclassing_any is enabled and _ProtocolMeta
@@ -49,6 +65,8 @@ class PhantomSized(
     bound=SizedIterable,
     abstract=True,
 ):
+    """Takes class argument ``len: Predicate[float]``."""
+
     def __init_subclass__(cls, len: Predicate[float], **kwargs: Any) -> None:
         super().__init_subclass__(
             predicate=boolean.both(
@@ -60,8 +78,8 @@ class PhantomSized(
 
 
 class NonEmpty(PhantomSized[T], Generic[T], len=numeric.greater(0)):
-    ...
+    """A sized collection with at least one item."""
 
 
 class Empty(PhantomSized[T], Generic[T], len=generic.equal(0)):
-    ...
+    """A sized collection with exactly zero items."""
